/**
 * 格式化日期
 * @param {Date} date - 要格式化的日期对象
 * @param {string} format - 格式字符串 (默认为 'YYYY-MM-DD')
 * @returns {string} 格式化后的日期字符串
 */
export function formatDate(date, format = 'YYYY-MM-DD') {
    if (!date) return '';

    const d = new Date(date);
    const year = d.getFullYear();
    const month = String(d.getMonth() + 1).padStart(2, '0');
    const day = String(d.getDate()).padStart(2, '0');
    const hours = String(d.getHours()).padStart(2, '0');
    const minutes = String(d.getMinutes()).padStart(2, '0');
    const seconds = String(d.getSeconds()).padStart(2, '0');

    return format
        .replace('YYYY', year)
        .replace('MM', month)
        .replace('DD', day)
        .replace('HH', hours)
        .replace('mm', minutes)
        .replace('ss', seconds);
}

/**
 * 格式化数字
 * @param {number} number - 要格式化的数字
 * @param {number} decimals - 小数位数
 * @param {string} decimalPoint - 小数点符号
 * @param {string} thousandsSeparator - 千位分隔符
 * @returns {string} 格式化后的数字字符串
 */
export function formatNumber(number, decimals = 0, decimalPoint = '.', thousandsSeparator = ',') {
    if (isNaN(number)) return '0';

    const n = Number(number).toFixed(decimals);
    return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, thousandsSeparator);
}
