import React, { useEffect, useState } from 'react';
import BrandsList from '../components/BrandsList';
import SearchBar from '../components/SearchBar';
import { Button, Modal, Form } from 'react-bootstrap';
import '../styles/Brands.scss';
import { useNavigate } from 'react-router-dom';
import { Plus } from 'lucide-react';
import { useDispatch } from 'react-redux';
import { selectBrand } from '../store/slices/brandsSlice';

export default function Brands() {
    const navigate = useNavigate();
    const dispatch = useDispatch();
    const [showAddBrandModal, setShowAddBrandModal] = useState(false);

    useEffect(() => {}, [dispatch]);

    const openBrandDetail = async (item) => {
        console.log(item);
        await dispatch(selectBrand(item));
        navigate(`/brands/${item.id}`);
    };

    return (
        <React.Fragment>
            <div className='function-bar'>
                <SearchBar />
                <Button onClick={() => setShowAddBrandModal(true)}>
                    <Plus />
                    Add Brand
                </Button>
            </div>
            <div className='breadcrumb'>
                <div className='breadcrumb-item'>Brands</div>
            </div>
            <BrandsList openBrandDetail={openBrandDetail} />
            <AddBrandModal show={showAddBrandModal} onHide={() => setShowAddBrandModal(false)} />
        </React.Fragment>
    );
}

function AddBrandModal({ show, onHide }) {
    const [brandName, setBrandName] = useState('');
    const [brandSource, setBrandSource] = useState('');
    const [campaignId, setCampaignId] = useState('');

    const sourceOptions = [
        { value: '1', label: 'Third Party Agency' },
        { value: '2', label: 'Official Event' },
        { value: '3', label: 'Social Media' },
    ];

    const handleCreateBrand = () => {
        console.log(brandName, brandSource, campaignId);
        handleCancel();
    };

    const handleCancel = () => {
        onHide();
        setBrandName('');
        setBrandSource('');
        setCampaignId('');
    };

    return (
        <Modal show={show} onHide={onHide} backdropClassName='modal-backdrop' container={document.body}>
            <Modal.Header>
                <Modal.Title>Add Brand</Modal.Title>
            </Modal.Header>
            <Modal.Body>
                <Form onSubmit={handleCreateBrand} className='add-brand-form'>
                    <Form.Group className='mb-3' controlId='formBasicName'>
                        <Form.Label>BrandName</Form.Label>
                        <Form.Control
                            type='text'
                            placeholder='Enter name'
                            value={brandName}
                            onChange={(e) => setBrandName(e.target.value)}
                        />
                    </Form.Group>
                    <Form.Group className='mb-3' controlId='formBasicSource'>
                        <Form.Label>Source</Form.Label>
                        <Form.Select value={brandSource} onChange={(e) => setBrandSource(e.target.value)}>
                            {sourceOptions.map((option) => (
                                <option key={option.value} value={option.value}>
                                    {option.label}
                                </option>
                            ))}
                        </Form.Select>
                    </Form.Group>
                    <Form.Group className='mb-3' controlId='formBasicCampaignId'>
                        <Form.Label>Campaign ID</Form.Label>
                        <Form.Control
                            type='text'
                            placeholder='Enter campaign ID'
                            value={campaignId}
                            onChange={(e) => setCampaignId(e.target.value)}
                        />
                    </Form.Group>
                    <div className='button-group'>
                        <Button variant='outline-light' className='text-primary' onClick={handleCancel}>
                            Cancel
                        </Button>
                        <Button variant='primary' onClick={handleCreateBrand}>
                            Create
                        </Button>
                    </div>
                </Form>
            </Modal.Body>
        </Modal>
    );
}
