import React, { useEffect, useState } from 'react';
import SearchBar from '../components/SearchBar';
import { Button } from 'react-bootstrap';
import { Folders, Hash, LinkIcon, Plus, Users } from 'lucide-react';
import { useDispatch, useSelector } from 'react-redux';
import { Link, useParams } from 'react-router-dom';
import CampaignList from '../components/CampaignList';
import ProductsList from '../components/ProductsList';
import { findBrandById } from '../store/slices/brandsSlice';

export default function BrandsDetail() {
    const { id } = useParams();
    const dispatch = useDispatch();
    const [activeTab, setActiveTab] = useState('campaigns');
    const { selectedBrand } = useSelector((state) => state.brands);

    useEffect(() => {
        if (id) {
            console.log(id);

            dispatch(findBrandById(id));
        }
    }, [dispatch, id]);

    return (
        selectedBrand?.id && (
            <React.Fragment>
                <div className='function-bar'>
                    <SearchBar />
                    {activeTab === 'campaigns' && (
                        <Button>
                            <Plus />
                            Add Campaign
                        </Button>
                    )}
                    {activeTab === 'products' && (
                        <Button>
                            <Plus />
                            Add Product
                        </Button>
                    )}
                </div>
                <div className='breadcrumb'>
                    <Link to={'/brands'} className='breadcrumb-item'>
                        Brands
                    </Link>
                    <div className='breadcrumb-item'>{selectedBrand.name}</div>
                </div>
                <div className='brand-detail-info'>
                    <div className='brand-logo shadow-xs'>{selectedBrand.name.toUpperCase()}</div>
                    <div className='brand-info shadow-xs'>
                        <div className='brand-info-top'>
                            <div className='info-item'>
                                <div className='info-name'>
                                    <Folders size={20} />
                                    商家分类
                                </div>
                                <div className='info-value'>{selectedBrand.category}</div>
                            </div>
                            <div className='info-item'>
                                <div className='info-name'>
                                    <LinkIcon size={20} />
                                    Source
                                </div>
                                <div className='info-value'>{selectedBrand.source}</div>
                            </div>
                            <div className='info-item'>
                                <div className='info-name'>
                                    <Hash size={20} />
                                    Collab.
                                </div>
                                <div className='info-value'>{selectedBrand.collab}</div>
                            </div>
                            <div className='info-item'>
                                <div className='info-name'>
                                    <Users size={20} />
                                    Creators
                                </div>
                                <div className='info-value'>{selectedBrand.creators}</div>
                            </div>
                        </div>
                        <div className='brand-info-bottom'>
                            <div className='info-item'>
                                <div className='info-value'>{selectedBrand.collab}</div>
                                <div className='info-name'>Total Collab. Creators</div>
                            </div>
                            <div className='info-item'>
                                <div className='info-value'>{selectedBrand.collab}</div>
                                <div className='info-name'>Total GMV Achieved</div>
                            </div>
                            <div className='info-item'>
                                <div className='info-value'>{selectedBrand.collab}</div>
                                <div className='info-name'>Total Views Achieved</div>
                            </div>
                            <div className='info-item'>
                                <div className='info-value'>{selectedBrand.collab}</div>
                                <div className='info-name'>Shop Overall Rating</div>
                            </div>
                        </div>
                    </div>
                </div>
                <div className='brand-tab-switches tab-switches'>
                    <div
                        className={`tab-switch-item ${activeTab === 'campaigns' ? 'active' : ''}`}
                        onClick={() => setActiveTab('campaigns')}
                    >
                        Campaigns
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'products' ? 'active' : ''}`}
                        onClick={() => setActiveTab('products')}
                    >
                        Products
                    </div>
                </div>
                {activeTab === 'campaigns' && <CampaignList />}
                {activeTab === 'products' && <ProductsList />}
            </React.Fragment>
        )
    );
}
