import { createSlice } from '@reduxjs/toolkit';

const initialState = {
    category: ['Homes Supplies'],
    ecommerceRatings: ['L2', 'L3'],
    exposureRatings: [],
    gmvRanges: ['$5k - $25k', '$25k - $60k'],
    viewsRange: [0, 100000],
    sortBy: 'followers',
    sortDirection: 'desc',
};

const filtersSlice = createSlice({
    name: 'filters',
    initialState,
    reducers: {
        setCategory: (state, action) => {
            const category = action.payload;
            if (state.category.includes(category)) {
                state.category = state.category.filter((r) => r !== category);
            } else {
                state.category.push(category);
            }
        },
        toggleEcommerceRating: (state, action) => {
            const rating = action.payload;
            if (state.ecommerceRatings.includes(rating)) {
                state.ecommerceRatings = state.ecommerceRatings.filter((r) => r !== rating);
            } else {
                state.ecommerceRatings.push(rating);
            }
        },
        toggleExposureRating: (state, action) => {
            const rating = action.payload;
            if (state.exposureRatings.includes(rating)) {
                state.exposureRatings = state.exposureRatings.filter((r) => r !== rating);
            } else {
                state.exposureRatings.push(rating);
            }
        },
        toggleGmvRange: (state, action) => {
            const range = action.payload;
            if (state.gmvRanges.includes(range)) {
                state.gmvRanges = state.gmvRanges.filter((r) => r !== range);
            } else {
                state.gmvRanges.push(range);
            }
        },
        setViewsRange: (state, action) => {
            state.viewsRange = action.payload;
        },
        setSortBy: (state, action) => {
            // 如果选择了当前已激活的排序项，则切换排序方向
            if (state.sortBy === action.payload) {
                state.sortDirection = state.sortDirection === 'asc' ? 'desc' : 'asc';
            } else {
                // 否则设置新的排序项，并重置排序方向为降序
                state.sortBy = action.payload;
                state.sortDirection = 'desc';
            }
        },
        resetFilters: () => {
            return initialState;
        },
    },
});

export const {
    setCategory,
    toggleEcommerceRating,
    toggleExposureRating,
    toggleGmvRange,
    setViewsRange,
    setSortBy,
    resetFilters,
} = filtersSlice.actions;

export default filtersSlice.reducer;
